<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\Libs\Service\CRUD;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\CTB\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\CTB\Services\Ctb93000EscrituracaoContabilFiscalService;

class Ctb93000EscrituracaoContabilFiscalController extends TeknisaCrud{

    protected $crudService;
    protected $parameterBag;
    protected $environment;
    protected $ctb93000EscrituracaoContabilFiscalService;

    public function __construct(CRUD $crudService, ParameterBag $parameterBag, Environment $environment, Ctb93000EscrituracaoContabilFiscalService $ctb93000EscrituracaoContabilFiscalService)
    {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->ctb93000EscrituracaoContabilFiscalService = $ctb93000EscrituracaoContabilFiscalService;
    }

    public function donwloadArquivo(Request\DataSet $dataset, Response $response){
        try {
            // Dados do Registro
            $arquivo  = $dataset->getDataSet()->getRows();
            
            // Arquivo para Download[Caminho + Nome + Extenção]
            $arquivo = $arquivo[0]['DSARQUIVO'];
            
            // Download Arquivo
            $this->ctb93000EscrituracaoContabilFiscalService->donwloadArquivo($arquivo);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function exportaECF(Row $row, Response $response){
        try {
            $row = $row->getRow();
            
            $cdempresa    = $row['CDEMPRESA'];
            $dtanoref     = $row['DTANOREF'];
            $idecfretifi  = $row['IDECFRETIFI'];
            $idecftransmi = $row['IDECFTRANSMI'];
            $nrrecibo     = isset($row['NRRECIBO'])?$row['NRRECIBO']:null;
            
            $nrseqarqmag = $this->ctb93000EscrituracaoContabilFiscalService->exportaECF(
                $cdempresa, $dtanoref, $idecfretifi, $idecftransmi, $nrrecibo
            );
            
            
            $response->addDataSet(new DataSet('arqmagnetico', ['nrseqarqmag' => $nrseqarqmag]));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    

}